aboutsummaryrefslogtreecommitdiff
path: root/gcc/ebitmap.h
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/ebitmap.h')
-rw-r--r--gcc/ebitmap.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/gcc/ebitmap.h b/gcc/ebitmap.h
index 175c911..f49a698 100644
--- a/gcc/ebitmap.h
+++ b/gcc/ebitmap.h
@@ -30,10 +30,10 @@ typedef struct ebitmap_def
{
unsigned int n_elts; /* number of elements in the array. */
sbitmap wordmask; /* wordmask saying which words are
- non-zero. */
- unsigned int numwords; /* number of non-zero words. */
+ nonzero. */
+ unsigned int numwords; /* number of nonzero words. */
unsigned int cacheindex; /* which word cache is. */
- EBITMAP_ELT_TYPE *elts; /* non-zero element array. */
+ EBITMAP_ELT_TYPE *elts; /* nonzero element array. */
EBITMAP_ELT_TYPE *cache; /* last tested element, or NULL. */
} *ebitmap;